==> graphflow-0.6.1.tar.gz: graphflow-0.6.1/README.md <==
# graphflow : Algorithms for Graph Flow Analysis

[![CircleCI](https://circleci.com/gh/stephenhky/GraphFlow.svg?style=svg)](https://circleci.com/gh/stephenhky/GraphFlow.svg)
[![GitHub release](https://img.shields.io/github/release/stephenhky/GraphFlow.svg?maxAge=3600)](https://github.com/stephenhky/GraphFlow/releases)
[![Documentation Status](https://readthedocs.org/projects/graphflow/badge/?version=latest)](https://graphflow.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/stephenhky/GraphFlow/shield.svg)](https://pyup.io/repos/github/stephenhky/GraphFlow/)
[![Python 3](https://pyup.io/repos/github/stephenhky/GraphFlow/python-3-shield.svg)](https://pyup.io/repos/github/stephenhky/GraphFlow/)
[![pypi](https://img.shields.io/pypi/v/graphflow.svg?maxAge=3600)](https://pypi.org/project/graphflow/)
[![download](https://img.shields.io/pypi/dm/graphflow.svg?maxAge=2592000&label=installs&color=%2327B1FF)](https://pypi.org/project/grapgflow/)
[![stars](https://img.shields.io/github/stars/stephenhky/GraphFlow.svg?style=social&label=Star&maxAge=60)](https://github.com/stephenhky/GraphFlow)


This Python package provides numerical routines for graph flow analysis, particularly:

* PageRank
* Linear System of Resistance
* Non-linear System of Resistance
* HITS (Hyperlink-Induced Topic Search)

# Installation

You must have `numpy` pre-installed. GCC and GFORTRAN compilers have to be available in the machine.
After ensuring they have been installed, type the following to install `graphflow`:

```
>>> pip install -U graphflow
```

# News

* 07/21/2023: `graphflow` 0.6.1 released.
* 10/10/2023: `graphflow` 0.6.0 released.
* 08/18/2023: `graphflow` 0.5.1 released.
* 06/20/2023: `graphflow` 0.5.0 released.
* 10/29/2022: `graphflow` 0.4.5 released.
* 10/04/2022: `graphflow` 0.4.4 released.
* 12/31/2021: `graphflow` 0.4.3 released.
* 12/15/2021: `graphflow` 0.4.2 released.
* 04/19/2021: `graphflow` 0.4.1 released.
* 04/10/2021: `graphflow` 0.4.0 released.
* 04/09/2020: `graphflow` 0.3.0 released.
* 04/07/2020: `graphflow` 0.2.1 released.
* 09/12/2018: `graphflow` 0.2.0 released.
* 09/03/2018: `graphflow` 0.1.6 released.
* 07/19/2018: `graphflow` 0.1.5 released.
* 06/27/2018: `graphflow` 0.1.4 released.
* 06/14/2018: `graphflow` 0.1.3 released.
* 06/06/2018: `graphflow` 0.1.2 released.
* 04/12/2018: `graphflow` 0.1.1 released.

==> graphflow-0.6.3.tar.gz: graphflow-0.6.3/README.md <==
# graphflow : Algorithms for Graph Flow Analysis

[![CircleCI](https://circleci.com/gh/stephenhky/GraphFlow.svg?style=svg)](https://circleci.com/gh/stephenhky/GraphFlow.svg)
[![GitHub release](https://img.shields.io/github/release/stephenhky/GraphFlow.svg?maxAge=3600)](https://github.com/stephenhky/GraphFlow/releases)
[![Documentation Status](https://readthedocs.org/projects/graphflow/badge/?version=latest)](https://graphflow.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/stephenhky/GraphFlow/shield.svg)](https://pyup.io/repos/github/stephenhky/GraphFlow/)
[![Python 3](https://pyup.io/repos/github/stephenhky/GraphFlow/python-3-shield.svg)](https://pyup.io/repos/github/stephenhky/GraphFlow/)
[![pypi](https://img.shields.io/pypi/v/graphflow.svg?maxAge=3600)](https://pypi.org/project/graphflow/)
[![download](https://img.shields.io/pypi/dm/graphflow.svg?maxAge=2592000&label=installs&color=%2327B1FF)](https://pypi.org/project/grapgflow/)
[![stars](https://img.shields.io/github/stars/stephenhky/GraphFlow.svg?style=social&label=Star&maxAge=60)](https://github.com/stephenhky/GraphFlow)


This Python package provides numerical routines for graph flow analysis, particularly:

* PageRank
* Linear System of Resistance
* Non-linear System of Resistance
* HITS (Hyperlink-Induced Topic Search)

# Installation

Type the following to install `graphflow`:

```
>>> pip install graphflow
```

# News

* 04/01/2025: `graphflow` 0.6.3 released.
* 12/02/2024: `graphflow` 0.6.2 released.
* 07/21/2023: `graphflow` 0.6.1 released.
* 10/10/2023: `graphflow` 0.6.0 released.
* 08/18/2023: `graphflow` 0.5.1 released.
* 06/20/2023: `graphflow` 0.5.0 released.
* 10/29/2022: `graphflow` 0.4.5 released.
* 10/04/2022: `graphflow` 0.4.4 released.
* 12/31/2021: `graphflow` 0.4.3 released.
* 12/15/2021: `graphflow` 0.4.2 released.
* 04/19/2021: `graphflow` 0.4.1 released.
* 04/10/2021: `graphflow` 0.4.0 released.
* 04/09/2020: `graphflow` 0.3.0 released.
* 04/07/2020: `graphflow` 0.2.1 released.
* 09/12/2018: `graphflow` 0.2.0 released.
* 09/03/2018: `graphflow` 0.1.6 released.
* 07/19/2018: `graphflow` 0.1.5 released.
* 06/27/2018: `graphflow` 0.1.4 released.
* 06/14/2018: `graphflow` 0.1.3 released.
* 06/06/2018: `graphflow` 0.1.2 released.
* 04/12/2018: `graphflow` 0.1.1 released.
